@@ -23,7 +23,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 sub ProcessFLIR($$;$);
 sub ProcessFLIRText($$$);
@@ -45,6 +45,7 @@ my %floatKelvin = (
 # commonly used tag information elements
 my %float1f = ( Format => 'float', PrintConv => 'sprintf("%.1f",$val)' );
 my %float2f = ( Format => 'float', PrintConv => 'sprintf("%.2f",$val)' );
+my %float6f = ( Format => 'float', PrintConv => 'sprintf("%.6f",$val)' );
 my %float8g = ( Format => 'float', PrintConv => 'sprintf("%.8g",$val)' );
 
 # FLIR makernotes tags (ref PH)
@@ -393,11 +394,11 @@ my %float8g = ( Format => 'float', PrintConv => 'sprintf("%.8g",$val)' );
     0x5c => { Name => 'PlanckB',  %float8g }, #1
     0x60 => { Name => 'PlanckF',  %float8g }, #1
     # 0x64,0x68,0x6c: 0
-    # 0x70 - float: 0.006568
-    # 0x74 - float: 0.012620
-    # 0x78 - float: -0.00227
-    # 0x7c - float: -0.00667
-    # 0x80 - float: 1.89999
+    0x070 => { Name => 'AtmosphericTransAlpha1', %float6f }, #1 (value: 0.006569)
+    0x074 => { Name => 'AtmosphericTransAlpha2', %float6f }, #1 (value: 0.012620)
+    0x078 => { Name => 'AtmosphericTransBeta1',  %float6f }, #1 (value: -0.002276)
+    0x07C => { Name => 'AtmosphericTransBeta2',  %float6f }, #1 (value: -0.006670)
+    0x080 => { Name => 'AtmosphericTransX',      %float6f }, #1 (value: 1.900000)
     # 0x84,0x88: 0
     # 0x8c - float: 0,4,6
     0x90 => { Name => 'CameraTemperatureRangeMax', %floatKelvin },
