@@ -22,7 +22,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:Public);
 
-$VERSION = '1.35';
+$VERSION = '1.40';
 
 sub JITTER() { return 2 }       # maximum time jitter
 
@@ -50,6 +50,7 @@ my %xmlTag = (
     sat         => 'nsats',     # GPX
     when        => 'time',      # KML
     coordinates => 'coords',    # KML
+    coord       => 'coords',    # KML, as written by Google Location History
     course      => 'dir',       # (written by Arduino)
     pitch       => 'pitch',     # (written by Arduino)
     roll        => 'roll',      # (written by Arduino)
@@ -108,22 +109,22 @@ my $secPerDay = 24 * 3600;      # a useful constant
 sub LoadTrackLog($$;$)
 {
     local ($_, $/, *EXIFTOOL_TRKFILE);
-    my ($exifTool, $val) = @_;
+    my ($et, $val) = @_;
     my ($raf, $from, $time, $isDate, $noDate, $noDateChanged, $lastDate, $dateFlarm);
     my ($nmeaStart, $fixSecs, @fixTimes, $lastFix, %nmea);
     my ($canCut, $cutPDOP, $cutHDOP, $cutSats);
 
-    unless (eval 'require Time::Local') {
+    unless (eval { require Time::Local }) {
         return 'Geotag feature requires Time::Local installed';
     }
     # add data to existing track
-    my $geotag = $exifTool->GetNewValues('Geotag') || { };
+    my $geotag = $et->GetNewValues('Geotag') || { };
     # get lookup for available information types
     my $has = $$geotag{Has};
     $has or $has = $$geotag{Has} = { 'pos' => 1 };
     my $format = '';
     # is $val track log data?
-    if ($val =~ /^(\xef\xbb\xbf)?<(\?xml|gpx)\s/) {
+    if ($val =~ /^(\xef\xbb\xbf)?<(\?xml|gpx)[\s>]/) {
         $format = 'XML';
         $/ = '>';   # set input record separator to '>' for XML/GPX data
     } elsif ($val =~ /(\x0d\x0a|\x0d|\x0a)/) {
@@ -137,7 +138,7 @@ sub LoadTrackLog($$;$)
             return "Empty track file '$val'";
         }
         # look for XML or GPX header (might as well allow UTF-8 BOM)
-        if (/^(\xef\xbb\xbf)?<(\?xml|gpx)\s/) {
+        if (/^(\xef\xbb\xbf)?<(\?xml|gpx)[\s>]/) {
             $format = 'XML';
             $/ = '>';   # set input record separator to '>' for XML/GPX data
         } elsif (/(\x0d\x0a|\x0d|\x0a)/) {
@@ -159,9 +160,9 @@ sub LoadTrackLog($$;$)
     $points or $points = $$geotag{Points} = { };
 
     # initialize cuts
-    my $maxHDOP = $exifTool->Options('GeoMaxHDOP');
-    my $maxPDOP = $exifTool->Options('GeoMaxPDOP');
-    my $minSats = $exifTool->Options('GeoMinSats');
+    my $maxHDOP = $et->Options('GeoMaxHDOP');
+    my $maxPDOP = $et->Options('GeoMaxPDOP');
+    my $minSats = $et->Options('GeoMinSats');
     my $isCut = $maxHDOP || $maxPDOP || $minSats;
 
     my $numPoints = 0;
@@ -206,6 +207,9 @@ sub LoadTrackLog($$;$)
         if ($format eq 'XML') {
             my ($arg, $tok, $td);
             s/\s*=\s*(['"])\s*/=$1/g;  # remove unnecessary white space in attributes
+            # Workaround for KML generated by Google Location History:
+            # lat/lon/alt are space-separated; we want commas.
+            s{(\S+)\s+(\S+)\s+(\S+)(</gx:coord>)}{$1,$2,$3$4};
             foreach $arg (split) {
                 # parse attributes (ie. GPX 'lat' and 'lon')
                 # (note: ignore namespace prefixes if they exist)
@@ -327,10 +331,10 @@ sub LoadTrackLog($$;$)
         } elsif ($nmea eq 'RMC') {
             #  $GPRMC,092204.999,A,4250.5589,S,14718.5084,E,0.00,89.68,211200,,*25
             #  $GPRMC,hhmmss.sss,A/V,ddmm.mmmm,N/S,ddmmm.mmmm,E/W,spd(knots),dir(deg),DDMMYY,,*cs
-            /^\$GPRMC,(\d{2})(\d{2})(\d+)(\.\d+)?,A,(\d+)(\d{2}\.\d+),([NS]),(\d+)(\d{2}\.\d+),([EW]),(\d*\.?\d*),(\d*\.?\d*),(\d{2})(\d{2})(\d+)/ or next;
+            /^\$GPRMC,(\d{2})(\d{2})(\d+)(\.\d+)?,A,(\d*?)(\d{1,2}\.\d+),([NS]),(\d*?)(\d{1,2}\.\d+),([EW]),(\d*\.?\d*),(\d*\.?\d*),(\d{2})(\d{2})(\d+)/ or next;
             next if $13 > 31 or $14 > 12 or $15 > 99;   # validate day/month/year
-            $fix{lat} = ($5 + $6/60) * ($7 eq 'N' ? 1 : -1);
-            $fix{lon} = ($8 + $9/60) * ($10 eq 'E' ? 1 : -1);
+            $fix{lat} = (($5 || 0) + $6/60) * ($7 eq 'N' ? 1 : -1);
+            $fix{lon} = (($8 || 0) + $9/60) * ($10 eq 'E' ? 1 : -1);
             $fix{speed} = $11 if length $11;
             $fix{track} = $12 if length $12;
             my $year = $15 + ($15 >= 70 ? 1900 : 2000);
@@ -343,9 +347,9 @@ sub LoadTrackLog($$;$)
         } elsif ($nmea eq 'GGA') {
             #  $GPGGA,092204.999,4250.5589,S,14718.5084,E,1,04,24.4,19.7,M,,,,0000*1F
             #  $GPGGA,hhmmss.sss,ddmm.mmmm,N/S,dddmm.mmmm,E/W,0=invalid,sats,hdop,alt,M,...
-            /^\$GPGGA,(\d{2})(\d{2})(\d+)(\.\d+)?,(\d+)(\d{2}\.\d+),([NS]),(\d+)(\d{2}\.\d+),([EW]),[1-6],(\d+)?,(\.\d+|\d+\.?\d*)?,(-?\d+\.?\d*)?,M?,/ or next;
-            $fix{lat} = ($5 + $6/60) * ($7 eq 'N' ? 1 : -1);
-            $fix{lon} = ($8 + $9/60) * ($10 eq 'E' ? 1 : -1);
+            /^\$GPGGA,(\d{2})(\d{2})(\d+)(\.\d+)?,(\d*?)(\d{1,2}\.\d+),([NS]),(\d*?)(\d{1,2}\.\d+),([EW]),[1-6],(\d+)?,(\.\d+|\d+\.?\d*)?,(-?\d+\.?\d*)?,M?,/ or next;
+            $fix{lat} = (($5 || 0) + $6/60) * ($7 eq 'N' ? 1 : -1);
+            $fix{lon} = (($8 || 0) + $9/60) * ($10 eq 'E' ? 1 : -1);
             $fix{nsats} = $11;
             $fix{hdop} = $12;
             $fix{alt} = $13;
@@ -358,9 +362,9 @@ sub LoadTrackLog($$;$)
         } elsif ($nmea eq 'GLL') {
             #  $GPGLL,4250.5589,S,14718.5084,E,092204.999,A*2D
             #  $GPGLL,ddmm.mmmm,N/S,dddmm.mmmm,E/W,hhmmss.sss,A/V*cs
-            /^\$GPGLL,(\d+)(\d{2}\.\d+),([NS]),(\d+)(\d{2}\.\d+),([EW]),(\d{2})(\d{2})(\d+)(\.\d+),A/ or next;
-            $fix{lat} = ($1 + $2/60) * ($3 eq 'N' ? 1 : -1);
-            $fix{lon} = ($4 + $5/60) * ($6 eq 'E' ? 1 : -1);
+            /^\$GPGLL,(\d*?)(\d{1,2}\.\d+),([NS]),(\d*?)(\d{1,2}\.\d+),([EW]),(\d{2})(\d{2})(\d+)(\.\d+),A/ or next;
+            $fix{lat} = (($1 || 0) + $2/60) * ($3 eq 'N' ? 1 : -1);
+            $fix{lon} = (($4 || 0) + $5/60) * ($6 eq 'E' ? 1 : -1);
             $secs = (($7 * 60) + $8) * 60 + $9;
             $secs += $10 if $10;    # add fractional seconds
 #
@@ -499,9 +503,9 @@ sub LoadTrackLog($$;$)
     # set date flags
     if ($noDate and not $$geotag{NoDate}) {
         if ($isDate) {
-            $exifTool->Warn('Fixes are date-less -- will use time-only interpolation');
+            $et->Warn('Fixes are date-less -- will use time-only interpolation');
         } else {
-            $exifTool->Warn('Some fixes are date-less -- may use time-only interpolation');
+            $et->Warn('Some fixes are date-less -- may use time-only interpolation');
         }
         $$geotag{NoDate} = 1;
     }
@@ -539,9 +543,9 @@ sub LoadTrackLog($$;$)
         $$fix{first} = 1;
         last;
     }
-    my $verbose = $exifTool->Options('Verbose');
+    my $verbose = $et->Options('Verbose');
     if ($verbose) {
-        my $out = $exifTool->Options('TextOut');
+        my $out = $et->Options('TextOut');
         print $out "Loaded $numPoints points from GPS track log $from\n";
         print $out "Ignored $cutPDOP points due to GeoMaxPDOP cut\n" if $cutPDOP;
         print $out "Ignored $cutHDOP points due to GeoMaxHDOP cut\n" if $cutHDOP;
@@ -572,8 +576,8 @@ sub LoadTrackLog($$;$)
 # Returns: sync time difference (and updates input time), or undef if no sync
 sub ApplySyncCorr($$)
 {
-    my ($exifTool, $time) = @_;
-    my $sync = $exifTool->GetNewValues('Geosync');
+    my ($et, $time) = @_;
+    my $sync = $et->GetNewValues('Geosync');
     if (ref $sync eq 'HASH') {
         my $syncTimes = $$sync{Times};
         if ($syncTimes) {
@@ -633,7 +637,7 @@ sub ScanOutwards($$$$$$)
 # Returns: reference to fix hash or undef
 sub FindFix($$$$$$$)
 {
-    my ($exifTool, $key, $times, $points, $i, $dir, $maxSecs) = @_;
+    my ($et, $key, $times, $points, $i, $dir, $maxSecs) = @_;
     my ($t,$p);
     if ($dir) {
         ($t,$p) = ScanOutwards($key, $times, $points, $i, $dir, $maxSecs);
@@ -651,8 +655,8 @@ sub FindFix($$$$$$$)
             ($t, $p) = ($t2, $p2);
         }
     }
-    if (defined $p and $$exifTool{OPTIONS}{Verbose} > 2) {
-        $exifTool->VPrint(2, "  Taking $key from fix:\n", PrintFix($points, $t))
+    if (defined $p and $$et{OPTIONS}{Verbose} > 2) {
+        $et->VPrint(2, "  Taking $key from fix:\n", PrintFix($points, $t))
     }
     return $p;
 }
@@ -666,17 +670,17 @@ sub FindFix($$$$$$$)
 sub SetGeoValues($$;$)
 {
     local $_;
-    my ($exifTool, $val, $writeGroup) = @_;
-    my $geotag = $exifTool->GetNewValues('Geotag');
-    my $verbose = $exifTool->Options('Verbose');
+    my ($et, $val, $writeGroup) = @_;
+    my $geotag = $et->GetNewValues('Geotag');
+    my $verbose = $et->Options('Verbose');
     my ($fix, $time, $fsec, $noDate, $secondTry, $iExt, $iDir);
 
     # remove date if none of our fixes had date information
     $val =~ s/^\S+\s+// if $val and $geotag and not $$geotag{IsDate};
 
     # maximum time (sec) from nearest GPS fix when position is still considered valid
-    my $geoMaxIntSecs = $exifTool->Options('GeoMaxIntSecs');
-    my $geoMaxExtSecs = $exifTool->Options('GeoMaxExtSecs');
+    my $geoMaxIntSecs = $et->Options('GeoMaxIntSecs');
+    my $geoMaxExtSecs = $et->Options('GeoMaxExtSecs');
 
     # use 30 minutes for a default
     defined $geoMaxIntSecs or $geoMaxIntSecs = 1800;
@@ -701,7 +705,7 @@ sub SetGeoValues($$;$)
             $err = 'GPS track is empty';
             last;
         }
-        unless (eval 'require Time::Local') {
+        unless (eval { require Time::Local }) {
             $err = 'Geotag feature requires Time::Local installed';
             last;
         }
@@ -738,13 +742,13 @@ sub SetGeoValues($$;$)
         $time %= $secPerDay if $noDate;
 
         # apply time synchronization if available
-        my $sync = ApplySyncCorr($exifTool, $time);
+        my $sync = ApplySyncCorr($et, $time);
 
         # save fractional seconds string
         $fsec = ($time =~ /(\.\d+)$/) ? $1 : '';
 
-        if ($exifTool->Options('Verbose') > 1 and not $secondTry) {
-            my $out = $exifTool->Options('TextOut');
+        if ($et->Options('Verbose') > 1 and not $secondTry) {
+            my $out = $et->Options('TextOut');
             my $str = "$fsec UTC";
             $str .= sprintf(" (incl. Geosync offset of %+.3f sec)", $sync) if defined $sync;
             unless ($tz) {
@@ -760,7 +764,7 @@ sub SetGeoValues($$;$)
             } else {
                 $fix = $$points{$$times[0]};
                 $iExt = 0;  $iDir = 1;
-                $exifTool->VPrint(2, "  Taking pos from fix:\n",
+                $et->VPrint(2, "  Taking pos from fix:\n",
                     PrintFix($points, $$times[0])) if $verbose > 2;
             }
         } elsif ($time > $$times[-1]) {
@@ -769,7 +773,7 @@ sub SetGeoValues($$;$)
             } else {
                 $fix = $$points{$$times[-1]};
                 $iExt = $#$times;  $iDir = -1;
-                $exifTool->VPrint(2, "  Taking pos from fix:\n",
+                $et->VPrint(2, "  Taking pos from fix:\n",
                     PrintFix($points, $$times[-1])) if $verbose > 2;
             }
         } else {
@@ -804,13 +808,13 @@ sub SetGeoValues($$;$)
                     $err or $err = 'Time is too far from nearest GPS fix';
                 } else {
                     $fix = $$points{$tn};
-                    $exifTool->VPrint(2, "  Taking pos from fix:\n",
+                    $et->VPrint(2, "  Taking pos from fix:\n",
                         PrintFix($points, $tn)) if $verbose > 2;
                 }
             } else {
                 my $f0 = $t1 == $t0 ? 0 : ($time - $t0) / ($t1 - $t0);
                 my $p0 = $$points{$t0};
-                $exifTool->VPrint(2, "  Interpolating pos between fixes (f=$f0):\n",
+                $et->VPrint(2, "  Interpolating pos between fixes (f=$f0):\n",
                     PrintFix($points, $t0, $t1)) if $verbose > 2;
                 $fix = { };
                 # loop through available fix information categories
@@ -849,7 +853,7 @@ Category:       foreach $category (qw{pos track alt orient}) {
                             }
                             # re-calculate the interpolation factor
                             $f = $f0b = $t1b == $t0b ? 0 : ($time - $t0b) / ($t1b - $t0b);
-                            $exifTool->VPrint(2, "  Interpolating $category between fixes (f=$f):\n",
+                            $et->VPrint(2, "  Interpolating $category between fixes (f=$f):\n",
                                 PrintFix($points, $t0b, $t1b)) if $verbose > 2;
                         }
                         # must interpolate cyclical values differently
@@ -889,7 +893,7 @@ Category:       foreach $category (qw{pos track alt orient}) {
             $gpsAlt = abs $$fix{alt};
             $gpsAltRef = ($$fix{alt} < 0 ? 1 : 0);
         } elsif ($$has{alt} and defined $iExt) {
-            my $tFix = FindFix($exifTool,'alt',$times,$points,$iExt,$iDir,$geoMaxExtSecs);
+            my $tFix = FindFix($et,'alt',$times,$points,$iExt,$iDir,$geoMaxExtSecs);
             if ($tFix) {
                 $gpsAlt = abs $$tFix{alt};
                 $gpsAltRef = ($$tFix{alt} < 0 ? 1 : 0);
@@ -904,56 +908,57 @@ Category:       foreach $category (qw{pos track alt orient}) {
             $exif = ($writeGroup =~ /^(exif|gps)$/i);
         }
         # (capture error messages by calling SetNewValue in list context)
-        @r = $exifTool->SetNewValue(GPSLatitude => $$fix{lat}, %opts);
-        @r = $exifTool->SetNewValue(GPSLongitude => $$fix{lon}, %opts);
-        @r = $exifTool->SetNewValue(GPSAltitude => $gpsAlt, %opts);
-        @r = $exifTool->SetNewValue(GPSAltitudeRef => $gpsAltRef, %opts);
+        @r = $et->SetNewValue(GPSLatitude => $$fix{lat}, %opts);
+        @r = $et->SetNewValue(GPSLongitude => $$fix{lon}, %opts);
+        @r = $et->SetNewValue(GPSAltitude => $gpsAlt, %opts);
+        @r = $et->SetNewValue(GPSAltitudeRef => $gpsAltRef, %opts);
         if ($$has{track}) {
             my $tFix = $fix;
             if (not defined $$fix{track} and defined $iExt) {
-                my $p = FindFix($exifTool,'track',$times,$points,$iExt,$iDir,$geoMaxExtSecs);
+                my $p = FindFix($et,'track',$times,$points,$iExt,$iDir,$geoMaxExtSecs);
                 $tFix = $p if $p;
             }
-            @r = $exifTool->SetNewValue(GPSTrack => $$tFix{track}, %opts);
-            @r = $exifTool->SetNewValue(GPSTrackRef => (defined $$tFix{track} ? 'T' : undef), %opts);
-            @r = $exifTool->SetNewValue(GPSSpeed => $$tFix{speed}, %opts);
-            @r = $exifTool->SetNewValue(GPSSpeedRef => (defined $$tFix{speed} ? 'N' : undef), %opts);
+            @r = $et->SetNewValue(GPSTrack => $$tFix{track}, %opts);
+            @r = $et->SetNewValue(GPSTrackRef => (defined $$tFix{track} ? 'T' : undef), %opts);
+            @r = $et->SetNewValue(GPSSpeed => $$tFix{speed}, %opts);
+            @r = $et->SetNewValue(GPSSpeedRef => (defined $$tFix{speed} ? 'N' : undef), %opts);
         }
         if ($$has{orient}) {
             my $tFix = $fix;
             if (not defined $$fix{dir} and defined $iExt) {
-                my $p = FindFix($exifTool,'dir',$times,$points,$iExt,$iDir,$geoMaxExtSecs);
+                my $p = FindFix($et,'dir',$times,$points,$iExt,$iDir,$geoMaxExtSecs);
                 $tFix = $p if $p;
             }
-            @r = $exifTool->SetNewValue(GPSImgDirection => $$tFix{dir}, %opts);
-            @r = $exifTool->SetNewValue(GPSImgDirectionRef => (defined $$tFix{dir} ? 'T' : undef), %opts);
+            @r = $et->SetNewValue(GPSImgDirection => $$tFix{dir}, %opts);
+            @r = $et->SetNewValue(GPSImgDirectionRef => (defined $$tFix{dir} ? 'T' : undef), %opts);
             # Note: GPSPitch and GPSRoll are non-standard, and must be user-defined
-            @r = $exifTool->SetNewValue(GPSPitch => $$tFix{pitch}, %opts);
-            @r = $exifTool->SetNewValue(GPSRoll => $$tFix{roll}, %opts);
+            @r = $et->SetNewValue(GPSPitch => $$tFix{pitch}, %opts);
+            @r = $et->SetNewValue(GPSRoll => $$tFix{roll}, %opts);
         }
         unless ($xmp) {
-            @r = $exifTool->SetNewValue(GPSLatitudeRef => ($$fix{lat} > 0 ? 'N' : 'S'), %opts);
-            @r = $exifTool->SetNewValue(GPSLongitudeRef => ($$fix{lon} > 0 ? 'E' : 'W'), %opts);
-            @r = $exifTool->SetNewValue(GPSDateStamp => $gpsDate, %opts);
-            @r = $exifTool->SetNewValue(GPSTimeStamp => $gpsTime, %opts);
+            @r = $et->SetNewValue(GPSLatitudeRef => ($$fix{lat} > 0 ? 'N' : 'S'), %opts);
+            @r = $et->SetNewValue(GPSLongitudeRef => ($$fix{lon} > 0 ? 'E' : 'W'), %opts);
+            @r = $et->SetNewValue(GPSDateStamp => $gpsDate, %opts);
+            @r = $et->SetNewValue(GPSTimeStamp => $gpsTime, %opts);
             # set options to edit XMP:GPSDateTime only if it already exists
             $opts{EditOnly} = 1;
             $opts{Group} = 'XMP';
         }
         unless ($exif) {
-            @r = $exifTool->SetNewValue(GPSDateTime => "$gpsDate $gpsTime", %opts);
+            @r = $et->SetNewValue(GPSDateTime => "$gpsDate $gpsTime", %opts);
         }
     } else {
         my %opts;
         $opts{Replace} = 2 if defined $val; # remove existing new values
         $opts{Group} = $writeGroup if $writeGroup;
+
         # reset any GPS values we might have already set
         foreach (qw(GPSLatitude GPSLatitudeRef GPSLongitude GPSLongitudeRef
                     GPSAltitude GPSAltitudeRef GPSDateStamp GPSTimeStamp GPSDateTime
                     GPSTrack GPSTrackRef GPSSpeed GPSSpeedRef
                     GPSImgDirection GPSImgDirectionRef GPSPitch GPSRoll))
         {
-            my @r = $exifTool->SetNewValue($_, undef, %opts);
+            my @r = $et->SetNewValue($_, undef, %opts);
         }
     }
     return $err;
@@ -969,8 +974,8 @@ Category:       foreach $category (qw{pos track alt orient}) {
 #        correction to be implemented
 sub ConvertGeosync($$)
 {
-    my ($exifTool, $val) = @_;
-    my $sync = $exifTool->GetNewValues('Geosync') || { };
+    my ($et, $val) = @_;
+    my $sync = $et->GetNewValues('Geosync') || { };
     my ($syncFile, $gpsTime, $imgTime);
 
     if ($val =~ /(.*?)\@(.*)/) {
@@ -998,7 +1003,7 @@ sub ConvertGeosync($$)
             foreach $tag (@timeTags) {
                 if ($$info{$tag}) {
                     $imgTime = $$info{$tag};
-                    $exifTool->VPrint(2, "Geosyncing with $tag from '$syncFile'\n");
+                    $et->VPrint(2, "Geosyncing with $tag from '$syncFile'\n");
                     last;
                 }
             }
@@ -1052,15 +1057,15 @@ sub ConvertGeosync($$)
             $$sync{Points} or $$sync{Points} = { };
             $$sync{Points}{$imgSecs} = $$sync{Offset};
             # print verbose output
-            if ($exifTool->Options('Verbose') > 1) {
+            if ($et->Options('Verbose') > 1) {
                 # print GPS and image timestamps in UTC
                 my $gps = Image::ExifTool::ConvertUnixTime($gpsSecs);
                 my $img = Image::ExifTool::ConvertUnixTime($imgSecs);
                 $gps .= $1 if $gpsTime =~ /(\.\d+)/;
                 $img .= $1 if $imgTime =~ /(\.\d+)/;
-                $exifTool->VPrint(1, "Added Geosync point:\n",
-                                     "  GPS time stamp:  $gps UTC\n",
-                                     "  Image date/time: $img UTC\n");
+                $et->VPrint(1, "Added Geosync point:\n",
+                               "  GPS time stamp:  $gps UTC\n",
+                               "  Image date/time: $img UTC\n");
             }
             # save sorted list of image sync times if we have more than one
             my @times = keys %{$$sync{Points}};
@@ -1140,7 +1145,7 @@ user-defined tags, GPSPitch and GPSRoll, must be active.
 
 =head1 AUTHOR
 
-Copyright 2003-2013, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -1169,4 +1174,3 @@ L<Image::ExifTool::TagNames/Extra Tags>,
 L<Image::ExifTool(3pm)|Image::ExifTool>
 
 =cut
-
