@@ -16,7 +16,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::XMP;
 
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 sub ProcessXtra($$$);
 
@@ -132,6 +132,11 @@ sub ProcessXtra($$$);
 my %sRegions = (
     STRUCT_NAME => 'Microsoft Regions',
     NAMESPACE   => 'MPReg',
+    NOTES => q{
+        Note that PersonLiveIdCID element is called PersonLiveCID according to the
+        Microsoft specification, but in practice their software actually writes
+        PersonLiveIdCID, so ExifTool uses this too.
+    },
     Rectangle         => { },
     PersonDisplayName => { },
     PersonEmailDigest => { },
